---
name: Bug report
about: Create a report to help us improve
title: XYZ doesn't work as intended
labels: bug
assignees: LOENS2

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Desktop (please complete the following information):**
 - Distribution: [e.g. Ubuntu]
 - Browser [e.g. chrome, safari]
 - Version [e.g. 22.04]
 - Python version [e.g 3.11]
 - Prometheus version [e.g 2.37.0]
 - Pterodactyl Panel version [e.g. 1.10.1]

**Additional context**
Add any other context about the problem here.
